summaryrefslogtreecommitdiffstats
path: root/parts/filter/shellinsertdlg.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'parts/filter/shellinsertdlg.cpp')
-rw-r--r--parts/filter/shellinsertdlg.cpp44
1 files changed, 22 insertions, 22 deletions
diff --git a/parts/filter/shellinsertdlg.cpp b/parts/filter/shellinsertdlg.cpp
index a1474ed2..e36278b5 100644
--- a/parts/filter/shellinsertdlg.cpp
+++ b/parts/filter/shellinsertdlg.cpp
@@ -11,9 +11,9 @@
#include "shellinsertdlg.h"
-#include <qcombobox.h>
-#include <qlayout.h>
-#include <qpushbutton.h>
+#include <tqcombobox.h>
+#include <tqlayout.h>
+#include <tqpushbutton.h>
#include <kconfig.h>
#include <kbuttonbox.h>
#include <kdebug.h>
@@ -30,11 +30,11 @@
ShellInsertDialog::ShellInsertDialog()
- : QDialog(0, "shell filter dialog", true)
+ : TQDialog(0, "shell filter dialog", true)
{
- QVBoxLayout *layout = new QVBoxLayout(this, 10, 4);
+ TQVBoxLayout *layout = new TQVBoxLayout(this, 10, 4);
- combo = new QComboBox(true, this);
+ combo = new TQComboBox(true, this);
combo->setDuplicatesEnabled(false);
layout->addWidget(combo);
@@ -45,16 +45,16 @@ ShellInsertDialog::ShellInsertDialog()
buttonbox->layout();
layout->addWidget(buttonbox);
- connect( start_button, SIGNAL(clicked()),
- this, SLOT(slotStartClicked()) );
- connect( cancel_button, SIGNAL(clicked()),
- this, SLOT(reject()) );
- connect( combo->lineEdit(), SIGNAL(textChanged( const QString &)), this, SLOT(executeTextChanged( const QString &)));
+ connect( start_button, TQT_SIGNAL(clicked()),
+ this, TQT_SLOT(slotStartClicked()) );
+ connect( cancel_button, TQT_SIGNAL(clicked()),
+ this, TQT_SLOT(reject()) );
+ connect( combo->lineEdit(), TQT_SIGNAL(textChanged( const TQString &)), this, TQT_SLOT(executeTextChanged( const TQString &)));
m_proc = 0;
KConfig *config = FilterFactory::instance()->config();
config->setGroup("General");
- QStringList items = config->readListEntry("InsertItems");
+ TQStringList items = config->readListEntry("InsertItems");
combo->insertStringList(items);
executeTextChanged( combo->lineEdit()->text());
@@ -66,8 +66,8 @@ ShellInsertDialog::~ShellInsertDialog()
kdDebug(9029) << "~ShellInsertDialog" << endl;
delete m_proc;
- // QComboBox API is a bit incomplete :-(
- QStringList list;
+ // TQComboBox API is a bit incomplete :-(
+ TQStringList list;
for (int i=0; i < combo->count(); ++i)
list << combo->text(i);
@@ -77,7 +77,7 @@ ShellInsertDialog::~ShellInsertDialog()
}
-void ShellInsertDialog::executeTextChanged( const QString &text)
+void ShellInsertDialog::executeTextChanged( const TQString &text)
{
start_button->setEnabled(!text.isEmpty());
}
@@ -85,29 +85,29 @@ void ShellInsertDialog::executeTextChanged( const QString &text)
int ShellInsertDialog::exec()
{
start_button->setEnabled(true);
- return QDialog::exec();
+ return TQDialog::exec();
}
void ShellInsertDialog::slotStartClicked()
{
start_button->setEnabled(false);
- m_str = QCString();
+ m_str = TQCString();
delete m_proc;
m_proc = new KShellProcess("/bin/sh");
(*m_proc) << combo->currentText();
- connect( m_proc, SIGNAL(receivedStdout(KProcess*, char *, int)),
- this, SLOT(slotReceivedStdout(KProcess*, char *, int)) );
- connect( m_proc, SIGNAL(processExited(KProcess*)),
- this, SLOT(slotProcessExited(KProcess*)) );
+ connect( m_proc, TQT_SIGNAL(receivedStdout(KProcess*, char *, int)),
+ this, TQT_SLOT(slotReceivedStdout(KProcess*, char *, int)) );
+ connect( m_proc, TQT_SIGNAL(processExited(KProcess*)),
+ this, TQT_SLOT(slotProcessExited(KProcess*)) );
m_proc->start(KProcess::NotifyOnExit, KProcess::AllOutput);
}
void ShellInsertDialog::slotReceivedStdout(KProcess *, char *text, int len)
{
- m_str += QCString(text, len+1);
+ m_str += TQCString(text, len+1);
}